@@ -9,14 +9,19 @@ from ph_max_auto.phcontext.phcontextfacade import PhContextFacade
 
 
 @click.command()
+@click.option("-r", "--runtime", prompt="Your programming language is", help="You use programming language.",
+              type=click.Choice(["python3", "r"]), default="python3")
 @click.option("--cmd", prompt="Your command is", help="The command that you want to process.",
               type=click.Choice(["create", "combine", "dag", "publish", "run", "submit", "status"]))
 @click.option("-p", "--path", prompt="Your config and python job file directory",
               help="The concert job you want the process.")
 @click.option("-c", "--context", default="{}")
 @click.argument('args', nargs=1, default="{}")
-def maxauto(cmd, path, context, args):
+def maxauto(runtime, cmd, path, context, args):
     """The Pharbers Max Job Command Line Interface (CLI)
+        --runtime Args: \n
+            python: This is to see \n
+            R: This is to see \n
 
         --cmd Args: \n
             create: to generate a job template \n
@@ -26,5 +31,5 @@ def maxauto(cmd, path, context, args):
         --path Args: \n
             the dictionary that specify the py and yaml file
     """
-    facade = PhContextFacade(cmd, path, context, args)
+    facade = PhContextFacade(runtime, cmd, path, context, args)
     click.get_current_context().exit(facade.execute())
